@@ -6,14 +6,15 @@ Puppet::Type.newtype(:glance_image) do
 
     glance_image { "Ubuntu 12.04 cloudimg amd64":
       ensure           => present,
-      name             => "Ubuntu 12.04 cloudimg amd64"
+      name             => "Ubuntu 12.04 cloudimg amd64",
       is_public        => yes,
-      container_format => ovf,
+      container_format => 'ovf',
       disk_format      => 'qcow2',
-      source           => 'http://uec-images.ubuntu.com/releases/precise/release/ubuntu-12.04-server-cloudimg-amd64-disk1.img'
+      source           => 'http://uec-images.ubuntu.com/releases/precise/release/ubuntu-12.04-server-cloudimg-amd64-disk1.img',
+      proxy            => 'http://127.0.0.1:8080',
       min_ram          => 1234,
       min_disk         => 1234,
-      properties       => { 'img_key' => img_value }
+      properties       => { 'img_key' => img_value },
     }
 
     Known problems / limitations:
@@ -65,7 +66,7 @@ Puppet::Type.newtype(:glance_image) do
 
   newproperty(:disk_format) do
     desc "The format of the disk"
-    newvalues(:ami, :ari, :aki, :vhd, :vmdk, :raw, :qcow2, :vdi, :iso)
+    newvalues(:ami, :ari, :aki, :vhd, :vmdk, :raw, :qcow2, :vdi, :iso, :ploop)
   end
 
   newparam(:source) do
@@ -73,6 +74,11 @@ Puppet::Type.newtype(:glance_image) do
     newvalues(/\S+/)
   end
 
+  newparam(:proxy) do
+    desc "The proxy server to use if source should be downloaded"
+    newvalues(/\S+/)
+  end
+
   newproperty(:min_ram) do
     desc "The minimal ram size"
     newvalues(/\d+/)
@@ -89,9 +95,7 @@ Puppet::Type.newtype(:glance_image) do
     munge do |value|
       return value if value.is_a? Hash
 
-      # wrap property value in commas
-      value.gsub!(/=(\w+)/, '=\'\1\'')
-      Hash[value.scan(/(\S+)='([^']*)'/)]
+      Hash[value.scan(/([^,=]+)=([^,]*)/)]
     end
 
     validate do |value|
