@@ -8,48 +8,14 @@ describe 'glance class' do
       include ::openstack_integration::repos
       include ::openstack_integration::mysql
       include ::openstack_integration::keystone
-
-      # Glance resources
-      include ::glance
-      include ::glance::client
-      include ::glance::backend::file
-      class { '::glance::db::mysql':
-        # https://bugs.launchpad.net/puppet-glance/+bug/1446375
-        collate  => 'utf8_general_ci',
-        password => 'a_big_secret',
-      }
-      class { '::glance::keystone::auth':
-        password => 'a_big_secret',
-      }
-      class { '::glance::keystone::glare_auth':
-        password => 'a_big_secret',
-      }
-      class { '::glance::api::authtoken':
-        password => 'a_big_secret',
-      }
-      class { '::glance::api':
-        database_connection => 'mysql+pymysql://glance:a_big_secret@127.0.0.1/glance?charset=utf8',
-      }
-      class { '::glance::registry::authtoken':
-        password => 'a_big_secret',
-      }
-      class { '::glance::registry':
-        database_connection => 'mysql+pymysql://glance:a_big_secret@127.0.0.1/glance?charset=utf8',
-      }
-      class { '::glance::glare::db':
-        database_connection => 'mysql+pymysql://glance:a_big_secret@127.0.0.1/glance?charset=utf8',
-      }
-      class { '::glance::glare::authtoken':
-        password => 'a_big_secret',
-      }
-      include ::glance::glare
+      include ::openstack_integration::glance
 
       glance_image { 'test_image':
         ensure           => present,
         container_format => 'bare',
         disk_format      => 'qcow2',
         is_public        => 'yes',
-        source           => 'http://download.cirros-cloud.net/0.3.1/cirros-0.3.1-x86_64-disk.img',
+        source           => 'http://download.cirros-cloud.net/0.3.5/cirros-0.3.5-x86_64-disk.img',
         min_ram          => '64',
         min_disk         => '1024',
         properties       => { 'icanhaz' => 'cheezburger' },
@@ -64,7 +30,7 @@ describe 'glance class' do
 
     describe 'glance images' do
       it 'should create a glance image with proper attributes' do
-        glance_env_opts = '--os-username glance --os-password a_big_secret --os-tenant-name services --os-auth-url http://127.0.0.1:5000/v2.0'
+        glance_env_opts = '--os-identity-api-version 3 --os-username glance --os-password a_big_secret --os-project-name services --os-user-domain-name Default --os-project-domain-name Default --os-auth-url http://127.0.0.1:5000/v3'
         shell("openstack #{glance_env_opts} image list") do |r|
           expect(r.stdout).to match(/test_image/)
         end
