@@ -11,7 +11,6 @@ describe 'basic glance config resource' do
       File <||> -> Glance_api_config <||>
       File <||> -> Glance_registry_config <||>
       File <||> -> Glance_cache_config <||>
-      File <||> -> Glance_glare_config <||>
 
       file { '/etc/glance' :
         ensure => directory,
@@ -25,9 +24,6 @@ describe 'basic glance config resource' do
       file { '/etc/glance/glance-cache.conf' :
         ensure => file,
       }
-      file { '/etc/glance/glance-glare.conf' :
-        ensure => file,
-      }
 
       glance_api_config { 'DEFAULT/thisshouldexist' :
         value => 'foo',
@@ -83,23 +79,6 @@ describe 'basic glance config resource' do
         ensure_absent_val => 'toto',
       }
 
-      glance_glare_config { 'DEFAULT/thisshouldexist' :
-        value => 'foo',
-      }
-
-      glance_glare_config { 'DEFAULT/thisshouldnotexist' :
-        value => '<SERVICE DEFAULT>',
-      }
-
-      glance_glare_config { 'DEFAULT/thisshouldexist2' :
-        value             => '<SERVICE DEFAULT>',
-        ensure_absent_val => 'toto',
-      }
-
-      glance_glare_config { 'DEFAULT/thisshouldnotexist2' :
-        value             => 'toto',
-        ensure_absent_val => 'toto',
-      }
       EOS
 
 
@@ -141,15 +120,5 @@ describe 'basic glance config resource' do
       end
     end
 
-    describe file('/etc/glance/glance-glare.conf') do
-      it { is_expected.to exist }
-      it { is_expected.to contain('thisshouldexist=foo') }
-      it { is_expected.to contain('thisshouldexist2=<SERVICE DEFAULT>') }
-
-      describe '#content' do
-        subject { super().content }
-        it { is_expected.not_to match /thisshouldnotexist/ }
-      end
-    end
   end
 end
