@@ -4,13 +4,17 @@ describe 'glance::api::db' do
 
   shared_examples 'glance::api::db' do
     context 'with default parameters' do
-      it { is_expected.to contain_glance_api_config('database/connection').with_value('sqlite:///var/lib/glance/glance.sqlite').with_secret(true) }
-      it { is_expected.to contain_glance_api_config('database/idle_timeout').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_glance_api_config('database/min_pool_size').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_glance_api_config('database/max_retries').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_glance_api_config('database/retry_interval').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_glance_api_config('database/max_pool_size').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_glance_api_config('database/max_overflow').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_oslo__db('glance_api_config').with(
+        :db_max_retries => '<SERVICE DEFAULT>',
+        :connection     => 'sqlite:///var/lib/glance/glance.sqlite',
+        :idle_timeout   => '<SERVICE DEFAULT>',
+        :min_pool_size  => '<SERVICE DEFAULT>',
+        :max_pool_size  => '<SERVICE DEFAULT>',
+        :max_retries    => '<SERVICE DEFAULT>',
+        :retry_interval => '<SERVICE DEFAULT>',
+        :max_overflow   => '<SERVICE DEFAULT>',
+        :pool_timeout   => '<SERVICE DEFAULT>',
+      )}
     end
 
     context 'with specific parameters' do
@@ -19,24 +23,30 @@ describe 'glance::api::db' do
           :database_idle_timeout   => '3601',
           :database_min_pool_size  => '2',
           :database_max_retries    => '11',
+          :database_db_max_retries => '-1',
           :database_retry_interval => '11',
           :database_max_pool_size  => '11',
           :database_max_overflow   => '21',
+          :database_pool_timeout   => '21',
         }
       end
 
-      it { is_expected.to contain_glance_api_config('database/connection').with_value('mysql+pymysql://glance_api:glance@localhost/glance').with_secret(true) }
-      it { is_expected.to contain_glance_api_config('database/idle_timeout').with_value('3601') }
-      it { is_expected.to contain_glance_api_config('database/min_pool_size').with_value('2') }
-      it { is_expected.to contain_glance_api_config('database/max_retries').with_value('11') }
-      it { is_expected.to contain_glance_api_config('database/retry_interval').with_value('11') }
-      it { is_expected.to contain_glance_api_config('database/max_pool_size').with_value('11') }
-      it { is_expected.to contain_glance_api_config('database/max_overflow').with_value('21') }
+      it { is_expected.to contain_oslo__db('glance_api_config').with(
+        :connection     => 'mysql+pymysql://glance_api:glance@localhost/glance',
+        :idle_timeout   => '3601',
+        :min_pool_size  => '2',
+        :max_pool_size  => '11',
+        :max_retries    => '11',
+        :db_max_retries => '-1',
+        :retry_interval => '11',
+        :max_overflow   => '21',
+        :pool_timeout   => '21',
+      )}
     end
 
     context 'with MySQL-python library as backend package' do
       let :params do
-        { :database_connection => 'mysql://glance_api:glance@localhost/glance' }
+        { :database_connection => 'mysql+pymysql://glance_api:glance@localhost/glance' }
       end
 
       it { is_expected.to contain_package('python-mysqldb').with(:ensure => 'present') }
@@ -59,7 +69,7 @@ describe 'glance::api::db' do
       end
 
       it 'install the proper backend package' do
-        is_expected.to contain_package('db_backend_package').with(
+        is_expected.to contain_package('python-pymysql').with(
           :ensure => 'present',
           :name   => 'python-pymysql',
           :tag    => 'openstack'
@@ -74,7 +84,6 @@ describe 'glance::api::db' do
         { :database_connection => 'mysql+pymysql://glance_api:glance@localhost/glance', }
       end
 
-      it { is_expected.not_to contain_package('db_backend_package') }
     end
   end
 
