@@ -1,6 +1,11 @@
 require 'spec_helper'
 
 describe 'glance::api' do
+  let :pre_condition do
+    "class { '::glance::api::authtoken':
+      password => 'ChangeMe',
+    }"
+  end
 
   let :default_params do
     {
@@ -18,16 +23,17 @@ describe 'glance::api' do
       :manage_service           => true,
       :backlog                  => '<SERVICE DEFAULT>',
       :workers                  => '7',
-      :keystone_password        => 'ChangeMe',
       :show_image_direct_url    => '<SERVICE DEFAULT>',
       :show_multiple_locations  => '<SERVICE DEFAULT>',
       :location_strategy        => '<SERVICE DEFAULT>',
       :purge_config             => false,
-      :known_stores             => false,
       :delayed_delete           => '<SERVICE DEFAULT>',
       :scrub_time               => '<SERVICE DEFAULT>',
       :default_store            => false,
       :image_cache_dir          => '/var/lib/glance/image-cache',
+      :enabled_import_methods   => '<SERVICE DEFAULT>',
+      :node_staging_uri         => '<SERVICE DEFAULT>',
+      :image_member_quota       => '<SERVICE DEFAULT>',
       :image_cache_stall_time   => '<SERVICE DEFAULT>',
       :image_cache_max_size     => '<SERVICE DEFAULT>',
       :os_region_name           => 'RegionOne',
@@ -38,13 +44,17 @@ describe 'glance::api' do
       :taskflow_engine_mode     => '<SERVICE DEFAULT>',
       :taskflow_max_workers     => '<SERVICE DEFAULT>',
       :conversion_format        => '<SERVICE DEFAULT>',
+      :enable_v1_api            => false,
+      :enable_v2_api            => '<SERVICE DEFAULT>',
+      :sync_db                  => true,
+      :limit_param_default      => '<SERVICE DEFAULT>',
+      :api_limit_max            => '<SERVICE DEFAULT>',
     }
   end
 
   shared_examples_for 'glance::api' do
 
-    [{:keystone_password => 'ChangeMe'},
-     {
+    [{
         :debug                    => true,
         :bind_host                => '127.0.0.1',
         :bind_port                => '9222',
@@ -55,17 +65,22 @@ describe 'glance::api' do
         :enabled                  => false,
         :backlog                  => '4095',
         :workers                  => '5',
-        :keystone_password        => 'ChangeMe',
         :show_image_direct_url    => true,
         :show_multiple_locations  => true,
         :location_strategy        => 'store_type',
         :delayed_delete           => 'true',
         :scrub_time               => '10',
         :image_cache_dir          => '/tmp/glance',
+        :enabled_import_methods   => 'glance-direct,web-download',
+        :node_staging_uri         => '/tmp/staging',
+        :image_member_quota       => '128',
         :image_cache_stall_time   => '10',
         :image_cache_max_size     => '10737418240',
         :os_region_name           => 'RegionOne2',
         :pipeline                 => 'keystone2',
+        :sync_db                  => false,
+        :limit_param_default      => '10',
+        :api_limit_max            => '10',
       }
     ].each do |param_set|
 
@@ -84,6 +99,13 @@ describe 'glance::api' do
         it { is_expected.to contain_class 'glance::api::logging' }
         it { is_expected.to contain_class 'glance::api::db' }
 
+        it 'is_expected.to not sync the db if sync_db is set to false' do
+
+          if !param_hash[:sync_db]
+            is_expected.not_to contain_exec('glance-manage db_sync')
+          end
+        end
+
         it { is_expected.to contain_service('glance-api').with(
           'ensure'     => (param_hash[:manage_service] && param_hash[:enabled]) ? 'running': 'stopped',
           'enable'     => param_hash[:enabled],
@@ -109,11 +131,23 @@ describe 'glance::api' do
             'delayed_delete',
             'scrub_time',
             'image_cache_dir',
+            'node_staging_uri',
+            'image_member_quota',
+            'enable_v1_api',
+            'enable_v2_api',
+            'limit_param_default',
+            'api_limit_max',
           ].each do |config|
             is_expected.to contain_glance_api_config("DEFAULT/#{config}").with_value(param_hash[config.intern])
           end
         end
 
+        it 'is_expected.to lay down default enabled_import_methods config' do
+          # Verify brackets "[]" are added to satisfy the ListOpt syntax.
+          is_expected.to contain_glance_api_config("DEFAULT/enabled_import_methods").with_value(
+                           "[%s]" % param_hash[:enabled_import_methods])
+        end
+
         it 'is_expected.to lay down default cache config' do
           [
             'registry_host',
@@ -164,9 +198,8 @@ describe 'glance::api' do
     describe 'with disabled service managing' do
       let :params do
         {
-          :keystone_password => 'ChangeMe',
-          :manage_service    => false,
-          :enabled           => false,
+          :manage_service => false,
+          :enabled        => false,
         }
       end
 
@@ -182,8 +215,7 @@ describe 'glance::api' do
     describe 'with overridden pipeline' do
       let :params do
         {
-          :keystone_password => 'ChangeMe',
-          :pipeline          => 'something',
+          :pipeline => 'something',
         }
       end
 
@@ -193,8 +225,7 @@ describe 'glance::api' do
     describe 'with blank pipeline' do
       let :params do
         {
-          :keystone_password => 'ChangeMe',
-          :pipeline          => '',
+          :pipeline => '',
         }
       end
 
@@ -225,7 +256,9 @@ describe 'glance::api' do
         default_params.merge({:enable_proxy_headers_parsing => true })
       end
 
-      it { is_expected.to contain_glance_api_config('oslo_middleware/enable_proxy_headers_parsing').with_value(true) }
+      it { is_expected.to contain_oslo__middleware('glance_api_config').with(
+        :enable_proxy_headers_parsing => true,
+      )}
     end
 
     describe 'with ssl options' do
@@ -255,7 +288,7 @@ describe 'glance::api' do
         default_params
       end
 
-      it { is_expected.to_not contain_glance_api_config('glance_store/stores').with_value('false') }
+      it { is_expected.to_not contain_glance_api_config('glance_store/stores').with_value('<SERVICE DEFAULT>') }
     end
 
     describe 'with stores override' do
@@ -295,18 +328,7 @@ describe 'glance::api' do
       it { is_expected.to contain_glance_api_config('glance_store/stores').with_value('file,http') }
     end
 
-    describe 'with both stores and known_stores provided' do
-      let :params do
-        default_params.merge({
-          :stores       => ['file'],
-          :known_stores => ['glance.store.http.store'],
-        })
-      end
-
-      it { is_expected.to raise_error(Puppet::Error, /known_stores and stores cannot both be assigned values/) }
-    end
-
-    describe 'with known_stores not set but with default_store' do
+    describe 'with default_store' do
       let :params do
         default_params.merge({
           :default_store => 'file',
@@ -346,28 +368,11 @@ describe 'glance::api' do
           :validate => true,
         })
       end
-      it { is_expected.to contain_exec('execute glance-api validation').with(
-        :path        => '/usr/bin:/bin:/usr/sbin:/sbin',
-        :provider    => 'shell',
-        :tries       => '10',
-        :try_sleep   => '2',
-        :command     => 'glance --os-auth-url http://127.0.0.1:5000 --os-project-name services --os-username glance --os-password ChangeMe image-list',
+      it { is_expected.to contain_openstacklib__service_validation('glance-api').with(
+        :command   => 'glance --os-auth-url http://127.0.0.1:5000 --os-project-name services --os-username glance --os-password ChangeMe image-list',
+        :subscribe => 'Service[glance-api]',
       )}
 
-      it { is_expected.to contain_anchor('create glance-api anchor').with(
-        :require => 'Exec[execute glance-api validation]',
-      )}
-    end
-
-    describe 'Support IPv6' do
-      let :params do
-        default_params.merge({
-          :registry_host => '2001::1',
-        })
-      end
-      it { is_expected.to contain_glance_api_config('DEFAULT/registry_host').with(
-        :value => '[2001::1]'
-      )}
     end
 
     describe 'while validating the service with custom command' do
@@ -377,42 +382,25 @@ describe 'glance::api' do
           :validation_options  => { 'glance-api' => { 'command' => 'my-script' } }
         })
       end
-      it { is_expected.to contain_exec('execute glance-api validation').with(
-        :path        => '/usr/bin:/bin:/usr/sbin:/sbin',
-        :provider    => 'shell',
-        :tries       => '10',
-        :try_sleep   => '2',
-        :command     => 'my-script',
+      it { is_expected.to contain_openstacklib__service_validation('glance-api').with(
+        :command   => 'my-script',
+        :subscribe => 'Service[glance-api]',
       )}
 
-      it { is_expected.to contain_anchor('create glance-api anchor').with(
-        :require => 'Exec[execute glance-api validation]',
-      )}
     end
 
-    describe 'with deprecated auth parameters' do
+    describe 'with barbican parameters' do
       let :params do
-        default_params.merge({
-          :auth_type         => 'keystone',
-          :keystone_tenant   => 'services',
-          :keystone_user     => 'glance',
-          :keystone_password => 'password',
-          :token_cache_time  => '1000',
-          :memcached_servers => 'localhost:11211',
-          :signing_dir       => '/tmp/keystone',
-          :auth_uri          => 'http://127.0.0.1:5000',
-          :identity_uri      => 'http://127.0.0.1:35357',
+        default_params.merge!({
+          :keymgr_backend             => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
+          :keymgr_encryption_api_url  => 'https://localhost:9311/v1',
+          :keymgr_encryption_auth_url => 'https://localhost:5000/v3',
         })
       end
-      it 'deprecated auth parameters' do
-        is_expected.to contain_glance_api_config('keystone_authtoken/memcached_servers').with_value(params[:memcached_servers])
-        is_expected.to contain_glance_api_config('keystone_authtoken/username').with_value(params[:keystone_user])
-        is_expected.to contain_glance_api_config('keystone_authtoken/project_name').with_value(params[:keystone_tenant])
-        is_expected.to contain_glance_api_config('keystone_authtoken/password').with_value(params[:keystone_password])
-        is_expected.to contain_glance_api_config('keystone_authtoken/token_cache_time').with_value(params[:token_cache_time])
-        is_expected.to contain_glance_api_config('keystone_authtoken/signing_dir').with_value(params[:signing_dir])
-        is_expected.to contain_glance_api_config('keystone_authtoken/auth_uri').with_value(params[:auth_uri])
-        is_expected.to contain_glance_api_config('keystone_authtoken/auth_url').with_value(params[:identity_uri])
+      it 'should set keymgr parameters' do
+        is_expected.to contain_glance_api_config('key_manager/backend').with_value('castellan.key_manager.barbican_key_manager.BarbicanKeyManager')
+        is_expected.to contain_glance_api_config('barbican/barbican_endpoint').with_value('https://localhost:9311/v1')
+        is_expected.to contain_glance_api_config('barbican/auth_endpoint').with_value('https://localhost:5000/v3')
       end
     end
   end
