@@ -10,14 +10,18 @@ describe 'glance::backend::swift' do
     end
 
     let :pre_condition do
-      'class { "glance::api": keystone_password => "pass" }'
+      'class { "glance::api::authtoken": password => "pass" }
+       include ::glance::api'
     end
 
     describe 'when default parameters' do
 
+      it { is_expected.to contain_class 'swift::client' }
+
       it 'configures glance-api.conf' do
         is_expected.to contain_glance_api_config('glance_store/default_store').with_value('swift')
         is_expected.to contain_glance_api_config('glance_store/swift_store_large_object_size').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_glance_api_config('glance_store/swift_store_large_object_chunk_size').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('glance_store/swift_store_container').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('glance_store/swift_store_create_container_on_put').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_glance_api_config('glance_store/swift_store_endpoint_type').with_value('internalURL')
@@ -31,17 +35,6 @@ describe 'glance::backend::swift' do
         is_expected.to contain_glance_swift_config('ref1/user_domain_id').with_value('default')
         is_expected.to contain_glance_swift_config('ref1/project_domain_id').with_value('default')
       end
-
-      it 'not configures glance-glare.conf' do
-        is_expected.to_not contain_glance_glare_config('glance_store/default_store').with_value('swift')
-        is_expected.to_not contain_glance_glare_config('glance_store/swift_store_large_object_size').with_value('<SERVICE DEFAULT>')
-        is_expected.to_not contain_glance_glare_config('glance_store/swift_store_container').with_value('<SERVICE DEFAULT>')
-        is_expected.to_not contain_glance_glare_config('glance_store/swift_store_create_container_on_put').with_value('<SERVICE DEFAULT>')
-        is_expected.to_not contain_glance_glare_config('glance_store/swift_store_endpoint_type').with_value('internalURL')
-        is_expected.to_not contain_glance_glare_config('glance_store/swift_store_region').with_value('<SERVICE DEFAULT>')
-        is_expected.to_not contain_glance_glare_config('glance_store/swift_store_config_file').with_value('/etc/glance/glance-swift.conf')
-        is_expected.to_not contain_glance_glare_config('glance_store/default_swift_reference').with_value('ref1')
-      end
     end
 
     describe 'when overriding parameters' do
@@ -53,13 +46,13 @@ describe 'glance::backend::swift' do
           :swift_store_auth_project_domain_id  => 'proj_domain',
           :swift_store_auth_user_domain_id     => 'user_domain',
           :swift_store_large_object_size       => '100',
+          :swift_store_large_object_chunk_size => '50',
           :swift_store_auth_address            => '127.0.0.2:8080/v1.0/',
           :swift_store_container               => 'swift',
           :swift_store_create_container_on_put => true,
           :swift_store_endpoint_type           => 'publicURL',
           :swift_store_region                  => 'RegionTwo',
           :default_swift_reference             => 'swift_creds',
-          :glare_enabled                       => true,
         }
       end
 
@@ -67,6 +60,7 @@ describe 'glance::backend::swift' do
         is_expected.to contain_glance_api_config('glance_store/swift_store_container').with_value('swift')
         is_expected.to contain_glance_api_config('glance_store/swift_store_create_container_on_put').with_value(true)
         is_expected.to contain_glance_api_config('glance_store/swift_store_large_object_size').with_value('100')
+        is_expected.to contain_glance_api_config('glance_store/swift_store_large_object_chunk_size').with_value('50')
         is_expected.to contain_glance_api_config('glance_store/swift_store_endpoint_type').with_value('publicURL')
         is_expected.to contain_glance_api_config('glance_store/swift_store_region').with_value('RegionTwo')
         is_expected.to contain_glance_api_config('glance_store/default_swift_reference').with_value('swift_creds')
@@ -77,15 +71,6 @@ describe 'glance::backend::swift' do
         is_expected.to contain_glance_swift_config('swift_creds/user_domain_id').with_value('user_domain')
         is_expected.to contain_glance_swift_config('swift_creds/project_domain_id').with_value('proj_domain')
       end
-
-      it 'configures glance-glare.conf' do
-        is_expected.to contain_glance_glare_config('glance_store/swift_store_container').with_value('swift')
-        is_expected.to contain_glance_glare_config('glance_store/swift_store_create_container_on_put').with_value(true)
-        is_expected.to contain_glance_glare_config('glance_store/swift_store_large_object_size').with_value('100')
-        is_expected.to contain_glance_glare_config('glance_store/swift_store_endpoint_type').with_value('publicURL')
-        is_expected.to contain_glance_glare_config('glance_store/swift_store_region').with_value('RegionTwo')
-        is_expected.to contain_glance_glare_config('glance_store/default_swift_reference').with_value('swift_creds')
-      end
     end
   end
 
